
============
*pynetdicom*
============

:gh:`pynetdicom <pynetdicom>` is a pure Python package
that implements the `DICOM <https://www.dicomstandard.org/>`_ networking protocol.
Working with
:gh:`pydicom <pydicom>`, it allows the easy creation
of DICOM Application Entities (AEs), which can then act as *Service Class
Users* (SCUs) and *Service Class Providers* (SCPs) by associating with other
AEs and using or providing the services available to the association.


User guide
==========
An overview for using *pynetdcom* and the concepts relevant to DICOM networking.

.. toctree::
   :maxdepth: 2

   user/index


Tutorials
=========

.. toctree::
   :maxdepth: 2

   tutorials/index


Examples
========
Example source code and applications.

.. toctree::
   :maxdepth: 2

   examples/index


Reference
=========
Documentation for `pynetdicom's` public functions, classes and other objects.

.. toctree::
    :maxdepth: 1

    reference/index


Services
========
Supported DICOM service classes.

.. toctree::
   :maxdepth: 2

   service_classes/index


Releases
========

.. toctree::
   :maxdepth: 1

   changelog/index
